pub struct CodeFragment { /* private fields */ }Expand description
A parsed, composable code fragment.
CodeFragment is for snippets that should preserve sigil-stitch structure
such as %> / %< indentation markers. Raw &str / String values passed
through %L remain literal text; use CodeFragment::of(...) when a fragment
contains format markers that must compose structurally inside another block.
Implementations
Sourceimpl CodeFragment
impl CodeFragment
Sourcepub fn of(format: &str, args: impl IntoArgs) -> Result<Self, SigilStitchError>
pub fn of(format: &str, args: impl IntoArgs) -> Result<Self, SigilStitchError>
Parse a format string and arguments into a composable fragment.
Sourcepub fn into_code_block(self) -> CodeBlock
pub fn into_code_block(self) -> CodeBlock
Convert this fragment into a CodeBlock.